#!/bin/bash
#
# CCLM NAMELIST INPUT

RES=$1
run=$2
inpath=$3
outpath=$4
procx=12
procy=12

# number of GRIBOUT blocks
ngribout=3

# changing variables...
if [ "$RES" == "C15" ]
then 
	STARTLON_TOT="-32.5"
	STARTLAT_TOT="-15."
	DLONLAT="0.125"
	IE_TOT="300"
	JE_TOT="300"
	DT="80.0"
	HINCBOUND="6"
	RLWIDTH="150000."
	LSSO=".TRUE."
fi
if [ "$RES" == "C05" ]
then 
	STARTLON_TOT="-25"
	STARTLAT_TOT="-10."
	DLONLAT="0.05"
	IE_TOT="500"
	JE_TOT="400"
	DT="30.0"
	HINCBOUND="1"
	RLWIDTH="60000."
	LSSO=".TRUE."
fi
if [ "$RES" == "C01" ]
then 
	STARTLON_TOT="-11.5"
	STARTLAT_TOT="-5."
	DLONLAT="0.01"
	IE_TOT="300"
	JE_TOT="400"
	DT="6.0"
	HINCBOUND="1"
	RLWIDTH="12000."
	LSSO=".FALSE."
fi

#############################################

cat > INPUT_ORG << end_input_org
 &LMGRID
  startlon_tot=$STARTLON_TOT, startlat_tot=$STARTLAT_TOT,
  pollat=12.5,        pollon=0.,          polgam=180.0,
  dlon=$DLONLAT,        dlat=$DLONLAT,
  ie_tot=$IE_TOT,       je_tot=$JE_TOT,          ke_tot=60,
 /
 &RUNCTL
  dt=$DT,
  hstart=0.0,   hstop=29.0,
  ydate_ini='${run}',
  lreproduce=.TRUE., luseobs=.FALSE., lphys=.TRUE.,
  ldiagnos=.TRUE., ldfi=.FALSE.,
  nprocx= ${procx}, nprocy= ${procy}, nprocio=0,
  nboundlines=3, ncomm_type=3, idbg_level=21,
  ldebug_io=.TRUE.,ldebug_dyn=.TRUE.,ldebug_soi=.TRUE.,
 /
 &TUNING
 /
end_input_org

cat > INPUT_IO  << end_input_io
 &IOCTL
  ngribout=$ngribout,
  yform_read='ncdf',
  !yform_write='ncdf', deleted in CCLM_5.0_clm1
  yncglob_title="Antarctica - Weddell Sea - resolution $RES modified by Rolf Zentek",
  yncglob_institution="University of Trier - Department of Environmental Meteorology"
  yncglob_contact = "zentek@uni-trier.de"
  yncglob_references = "http://www.clm-community.eu/",
  yncglob_project_id = "SPP 1158: Quantification of sea ice production in the southern Weddell sea",
  ytunit_restart='d',
  lbdclim=.TRUE.,
 /
 &DATABASE
 /
 &GRIBIN
  lan_t_s=.false., lan_t_so0=.true., lan_t_cl=.true., lan_w_cl=.true., lan_vio3=.true.,
  lan_hmo3=.true., lan_plcov=.true., lan_lai=.true., lan_rootdp=.true.,
  lan_w_i=.true., lan_t_snow=.true., lan_w_snow=.true., lan_rho_snow=.false.,
  hincbound=$HINCBOUND,
  lchkini=.TRUE., lchkbd =.TRUE., lbdana=.FALSE.,
  lana_qi=.TRUE., llb_qi=.TRUE., lana_rho_snow=.FALSE.,
  ydirini='${inpath}',
  ydirbd='${inpath}',
  ytunitbd='d',
 /

!out01: 3d variables (not centered in box) and forcing!!!
&GRIBOUT
  yform_write='ncdf',
  !ysystem='file',
  hcomb= 0.0,29.0,1.0, 
  l_p_filter=.FALSE.,
  l_z_filter=.FALSE.,
  yvarml='FRESHSNW','PP','QC','QI','QG','QR','QS','QV','QV_S','T','T_S','T_SNOW','T_SO','U','V','W','W_I','W_SNOW','W_SO',
		 'CLC','POT_VORTIC',
  yvarpl='',
  yvarzl='',
  luvmasspoint=.FALSE.,
  lcheck =.TRUE.,
  lwrite_const=.TRUE.,
  ydir='${outpath}/out01/',
  ytunit='d',
 /END

!out02: 2d variables (often used)
 &GRIBOUT
  yform_write='ncdf',
  !ysystem='file',
  hcomb= 0.0,29.0,1.0, 
  l_p_filter=.FALSE.,
  l_z_filter=.FALSE.,
  yvarzl='',
  yvarpl='',
  yvarml='RAIN_CON','SNOW_CON','RAIN_GSP','SNOW_GSP','GRAU_GSP','TOT_PREC',
		 'CLCT','CLCH','CLCL','CLCM','HPBL',
		 'DURSUN','PMSL','PS','QV_2M','RELHUM_2M',
		 'TD_2M','TD_2M_AV','T_2M','T_2M_AV','T_S','T_G'
		 'U_10M','U_10M_AV','V_10M','V_10M_AV',
		 'H_ICE','T_ICE','FR_ICE','Z0',
		 'AEVAP_S','H_SNOW','RUNOFF_G','RUNOFF_S','TQC','TQG','TQI','TQR','TQS','TQV','W_I','W_SNOW','SNOW_MELT',
		 'SOBS_RAD','ASOB_S','THBS_RAD','ATHB_S',
		 'AUMFL_S','AVMFL_S',
		 'LHFL_S','ALHFL_S','SHFL_S','ASHFL_S',
		 'LWD_S','ALWD_S','LWU_S','ALWU_S',
		 'SWDIFD_S','ASWDIFD_S','SWDIFU_S','ASWDIFU_S','SWDIR_S','ASWDIR_S',
		 'ALB_RAD','QVSFLX',
		 'SOB_T','ASOB_T','SOD_T','ASOD_T','THB_T','ATHB_T',
  luvmasspoint=.TRUE.,
  lcheck =.TRUE.,
  lwrite_const=.FALSE.,
  ydir='${outpath}/out02/',
  ytunit='d',
 /END

!out03: variables on pressure levels
 &GRIBOUT
  yform_write='ncdf',
  !ysystem='file',
  hcomb= 0.0,29.0,1.0, 
  l_p_filter=.FALSE.,
  l_z_filter=.FALSE.,
  yvarml='',
  yvarpl='FI','QV','T','U','V','W','RELHUM','OMEGA', 
  yvarzl='',
  plev=200,300,500,700,850,1000,
  luvmasspoint=.TRUE.,
  lcheck =.TRUE.,
  lwrite_const=.FALSE.,
  ydir='${outpath}/out03/',
  ytunit='d',
 /END
end_input_io

cat > INPUT_DYN << end_input_dyn
 &DYNCTL
  lexpl_lbc = .FALSE.,
  ldiabf_lh = .TRUE.,
  l2tls = .TRUE.,
   irunge_kutta = 1,
   iadv_order = 5,
   irk_order = 3,
   itype_fast_waves = 2,
  ldyn_bbc = .FALSE.,
  rlwidth = $RLWIDTH,
  nrdtau = 5,
  itype_bbc_w = 2,
  lspecnudge=.FALSE.,alpha_sn=0.05,
  isc_sn=6, jsc_sn=6,
  yvarsn='U     ','V    ',
  epsass=0.15,
  betasw=0.4,
  lspubc=.TRUE.,
  itype_hdiff=2,
  !hd_corr_q=0.5,
  !hd_corr_t=0.75,
  hd_dhmax=250.,
  eps_si=1E-8,
  ikrylow_si=20,
  iprint_si=0,
  lcond=.TRUE.,  
 /END
end_input_dyn



cat > INPUT_PHY << end_input_phy

&PHYCTL
  lgsp=.TRUE.,
    itype_gscp=4,
  lrad=.TRUE.,
    hincrad=1.0,
    icldm_rad=4,
    ico2_rad=0,
    lforest = .TRUE.,
  ltur = .TRUE.,
    itype_turb=3,
    imode_turb=0,
    icldm_turb=2,
    limpltkediff = .TRUE.,
    lexpcor = .TRUE.,
    ninctura=1,
    itype_tran = 1,
    imode_tran = 2,
    icldm_tran = 0,
    itype_synd = 2,
  lsoil = .TRUE.,
    lmulti_snow = .FALSE.,
    itype_evsl = 2,
    itype_trvg = 2,
    lmelt = .TRUE.,
    lmelt_var = .TRUE.,
    lmulti_layer = .TRUE.,
    ke_soil = 7,
    czml_soil = 0.005, 0.02, 0.06, 0.18, 0.54, 1.62, 4.86, 14.58,
    czbot_w_so=4.0,
  lconv = .TRUE.,
    nincconv = 10,
    itype_conv = 0,
    lconf_avg = .TRUE.,
  lsso=$LSSO,
  llake=.FALSE.,
  lseaice=.TRUE.,
  lkoltzow=.TRUE.,
  itype_sice=3,
    ltile=.FALSE.,
!!    itype_tile=2,
!!    tit_ocean=0.1,
!!    hice_crit=0.2,
/END

end_input_phy

cat > INPUT_DIA << end_input_dia
 &DIACTL
 /
end_input_dia

cat > INPUT_INI << end_input_ini
 &INICTL
  ndfi=0,
  tspan=3600.0, taus=3600.0,
  dtbak=$DT, dtfwd=$DT,
 /
end_input_ini

cat > INPUT_ASS << end_input_ass
 &NUDGING  
  lnudge  =.FALSE.,
 /
end_input_ass


