#!/bin/bash
# wraping script to start simulations on Mistral
# 04.2016 - zentek@uni-trier.de

RES="T15"
ScriptDir="/pf/b/b380225/weddellice/$RES/run"
if [ ! "$(pwd)" == "$ScriptDir" ]; then echo ERROR 1; exit 0; fi
Output="/scratch/b/b380225/COSMO_${RES}"
path2ForcingData="/work/bb0958/ERAinterim"
nSim=50 # number of simulation to queue at a time
sleeptime=300 # wait for 5 min if paused or queue is full

echo S T A R T
#################################################
for year in 2016 #$(seq 2007 2011)
do
    for month in 07 #$(seq -w 6 12)
    do
        for day in 05 #$(seq -w 1 $(cal $month $year | awk 'NF {DAYS = $NF}; END {print DAYS}'))
        do
            run="$year$month$day"
#for run in 20090518 20090624 20091026  #20070902 #20100812 #20070902 #20090512 20090816  #20050609 #20120418 #20120524 20130601
#do
			runStartTime=$(date -d "$run -1 day" +%Y%m%d)18
			echo ========== $run ==========
			echo ----- checking if less than $nSim simulations are queued in SLURM
				while [ "$nSim" -le "$(squeue -u b380225 | wc -l)" ]
				do
				    sleep $sleeptime
				done
			echo ----- checking if PAUSE==true
				while [ ! "false" == "$($ScriptDir/02_editMeToPauseSimulations.sh)" ]
				do
				    sleep $sleeptime
				done
			echo ----- making folders
				if [ -d $Output/$run ]; then rm -r $Output/$run; fi
				mkdir -p $Output/$run/input $Output/$run/out{01..03}
			echo ----- making Namelist
				cd $Output/$run/input
				$ScriptDir/03_make_INT2LM_Namelist.sh $RES $runStartTime $Output/$run/input domain_${RES}_$run.nc $path2ForcingData $Output/$run/input
				cd $Output/$run
				$ScriptDir/04_make_CCLM_Namelist.sh $RES $runStartTime $Output/$run/input $Output/$run
			echo ----- making slurm job
				sed "s%@RUNPATH%$Output/$run%g;s%@RES%$RES%g" $ScriptDir/template_run_int2lm.sbatch > $Output/$run/input/run_int2lm.sbatch
				sed "s%@RUNPATH%$Output/$run%g" $ScriptDir/template_run_cclm.sbatch > $Output/$run/run_cclm.sbatch
			echo ----- queuing slurm job
				cd $Output/$run/input
				sbatch $Output/$run/input/run_int2lm.sbatch
        done
    done
done
#################################################
echo D O N E
